import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Первый пример использования класса File
 * */

public class Main {
    /**
     * Лист для хранения расширений файлов
     * */
    private static List<String> extensions = new ArrayList<>();

    /**
     * Счетчик количества файлов с определенным расширением
     * */
    private static Map<String, Integer> counter = new HashMap<>();

    /**
     * Имя корневой папки
     * */
    private static String rootName;

    /**
     * Объект класса File, содержащий сведенья о корневой папке
     * */
    private static File root;

    /**
     * Функция для проверки аргументов переданных программе в командной строке.
     * Первым передается путь к папке, потом перечесляются сами расширения.
     * @param args аргументы командной строки
     * @return true, если были переданы корневая папка и расширения файлов, и false в противном случае
     * */
    private static boolean checkArgs(String[] args) {
        /*Провераяем, что мы передали путь к папке*/
        if (args.length == 0) {
            System.out.println("Введите путь до папки");
            return false;
        }

        rootName = args[0];
        root = new File(rootName);
        /*Проверяем, что ме передали путь к существующей папке*/
        if (!root.exists()) {
            System.out.println("Заданная папка не существует");
            return false;
        }

        /*Проверяем, что мы передали хотябы одно расширение файлов*/
        if (args.length == 1) {
            System.out.println("Введите расширения для поиска файлов");
            return false;
        }

        return true;
    }

    /**
     * Функция для заполнения списка расширений и инициализация счетчика вхождений расширений
     * @param args аргументы командной строки
     * */
    private static void buildExtensions(String[] args) {
        for (int i = 1; i < args.length; i++) {
            extensions.add(args[i]);
            counter.put(args[i], 0);
        }
    }

    /**
     * Функция для подсчета файлов с заданными рассширениями в текущей директории
     * @param directory текущая директория
     * */
    private static void countOfExpansions(File directory) {
        /*Обойдем все объекты в нашей папке*/
        for (File object : directory.listFiles()) {
            if (object.isFile()) {
                /*Проверим для каждого расширения*/
                for (String extension : extensions) {
                    /*Если наш файл имеет рассширение extension*/
                    if (object.getName().endsWith("." + extension)) {
                        /*то изменим значение количество у этого расширения*/
                        Integer countFiles = counter.get(extension);
                        counter.replace(extension, countFiles + 1);
                        break;
                    }
                }
            } else {
                countOfExpansions(object);
            }
        }
    }

    /**
     * Функция для вывода информации о количестве файлов с заданными расширениями
     * */
    private static void printCounter() {
        for (Map.Entry<String, Integer> entry : counter.entrySet()) {
            System.out.println(entry.getKey() + ": " + entry.getValue());
        }
    }

    public static void main(String[] args) {
        /*Если мы правильно передали программе аргументы*/
        if (checkArgs(args)) {
            /*Строим список расширений*/
            buildExtensions(args);

            /*Считаем количество вхождений файлов с заданными расширениями*/
            countOfExpansions(root);

            /*Выводим результат на экран*/
            printCounter();
        }
    }
}
